==> google-cloud-sdk-394.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/compute/queued_resources/list.py <==
# -*- coding: utf-8 -*- #
# Copyright 2022 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command for listing queued resources."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.compute import base_classes
from googlecloudsdk.api_lib.compute import lister
from googlecloudsdk.api_lib.compute import utils
from googlecloudsdk.calliope import arg_parsers
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.compute import completers as compute_completers
from googlecloudsdk.core.util.iso_duration import Duration
from googlecloudsdk.core.util.times import FormatDuration

DETAILED_HELP = {
    'DESCRIPTION':
        """\
        {command} displays all Compute Engine queued resources in a project
        in given zones.
      """,
    'EXAMPLES':
        """\
        To list all queued resources in a project in table form in specified zones, run:

        $ {command} --zones=us-central1-a,us-central1-b

        To list the URIs of all queued resources in a project in specified zones, run:

        $ {command} --zones=us-central1-a,us-central1-b --uri
    """
}


def _TransformMaxRunDuration(resource):
  """Properly format max_run_duration field."""
  # This will always be present in the resource.
  bulk_resource = resource.get('bulkInsertInstanceResource')

  # Use get with dictionary optional return value to skip existence checking
  max_run_duration = bulk_resource.get('instanceProperties',
                                       {}).get('scheduling',
                                               {}).get('maxRunDuration')
  if not max_run_duration:
    return ''
  duration = Duration(seconds=int(max_run_duration.get('seconds')))
  return FormatDuration(duration, parts=4)


class List(base.ListCommand):
  """List Compute Engine queued resources."""

  detailed_help = DETAILED_HELP

  @staticmethod
  def Args(parser):
    parser.display_info.AddFormat("""\
        table(
          name,
          location(),
          bulkInsertInstanceResource.count,
          bulkInsertInstanceResource.instanceProperties.machineType,
          bulkInsertInstanceResource.instanceProperties.guest_accelerators[0].accelerator_type,
          state,
          maxRunDuration(),
          status.queuingPolicy.validUntilTime
        )""")
    parser.display_info.AddTransforms({
        'maxRunDuration': _TransformMaxRunDuration,
    })
    parser.display_info.AddUriFunc(utils.MakeGetUriFunc())
    # TODO(b/212438138) Use lister.AddZonalListerArgs(parser).
    parser.add_argument(
        '--zones',
        metavar='ZONE',
        help='Only resources from the given zones are queried.',
        type=arg_parsers.ArgList(min_length=1),
        required=True,
        completer=compute_completers.ZonesCompleter,
        default=[])

  def Run(self, args):
    holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
    client = holder.client

    request_data = lister.ParseZonalFlags(args, holder.resources)

    list_implementation = lister.ZonalLister(
        client, client.apitools_client.zoneQueuedResources)

    return lister.Invoke(request_data, list_implementation)

==> google-cloud-sdk-454.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/compute/queued_resources/list.py <==
# -*- coding: utf-8 -*- #
# Copyright 2022 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command for listing queued resources."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.compute import base_classes
from googlecloudsdk.api_lib.compute import lister
from googlecloudsdk.api_lib.compute import utils
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.compute.queued_resources import flags


DETAILED_HELP = {
    'DESCRIPTION':
        """\
        {command} displays all Google Compute Engine queued resources in a
        project in given zones.
      """,
    'EXAMPLES':
        """\
        To list all queued resources in us-central1-b and europe-west1-d zones
        in a project in table form, run:

        $ {command} --zones=us-central1-b,europe-west1-d

        To list the URIs of all queued resources in us-central1-b zone in a
        project, run:

        $ {command} --zones=us-central1-b --uri
    """
}


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class List(base.ListCommand):
  """List Google Compute Engine queued resources."""

  @staticmethod
  def Args(parser):
    flags.AddOutputFormat(parser)
    parser.display_info.AddUriFunc(utils.MakeGetUriFunc())
    lister.AddBaseListerArgs(parser)
    lister.AddZoneArg(parser, hidden=False, required=True)

  def Run(self, args):
    holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
    client = holder.client

    request_data = lister.ParseZonalFlags(args, holder.resources)

    list_implementation = lister.ZonalLister(
        client, client.apitools_client.zoneQueuedResources)

    return lister.Invoke(request_data, list_implementation)

List.detailed_help = DETAILED_HELP
